Actions, Resources, and Condition Keys for DataSync - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to DataSync.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

The AWS Documentation website is getting a new look!
Try it now and let us know what you think. Switch to the new look >>
You can return to the original look by selecting English in the language selector above.

# Actions, Resources, and Condition Keys for DataSync

DataSync (service prefix: `datasync`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by DataSync
- Resources Defined by DataSync
- Condition Keys for DataSync

## Actions Defined by DataSync

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CancelTaskExecution | Cancels execution of a sync task. | Write | taskexecution* |  |
CreateAgent | Activates an agent that you have deployed on your host. | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateLocationEfs | Creates an endpoint for an Amazon EFS file system. | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateLocationNfs | Creates an endpoint for a NFS file system. | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateLocationS3 | Creates an endpoint for an Amazon S3 bucket. | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateLocationSmb | Creates an endpoint for an SMB file system. | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateTask | Creates a sync task. | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
DeleteAgent | Deletes an agent. | Write | agent* |  |
DeleteLocation | Deletes the configuration of a location used by AWS DataSync. | Write | location* |  |
DeleteTask | Deletes a sync task. | Write | task* |  |
DescribeAgent | Returns metadata such as name, network interfaces, and the status (that is, whether the agent is running or not) about a sync agent. | Read | agent* |  |
DescribeLocationEfs | Returns metadata, such as the path information about an Amazon EFS sync location. | Read | location* |  |
DescribeLocationNfs | Returns metadata, such as the path information, about a NFS sync location. | Read | location* |  |
DescribeLocationS3 | Returns metadata, such as bucket name, about an Amazon S3 bucket sync location. | Read | location* |  |
DescribeLocationSmb | Returns metadata, such as the path information, about an SMB sync location. | Read | location* |  |
DescribeTask | Returns metadata about a sync task. | Read | task* |  |
DescribeTaskExecution | Returns detailed metadata about a sync task that is being executed. | Read | taskexecution* |  |
ListAgents | Returns a list of agents owned by an AWS account in a region specified in the request. | List |  |  |
ListLocations | Returns a lists of source and destination sync locations. | List |  |  |
ListTagsForResource | This operation lists the tags that have been added to the specified resource. | Read | agent |  |
location |  |
task |  |
ListTaskExecutions | Returns a list of executed sync tasks. | List |  |  |
ListTasks | Returns a list of all the sync tasks. | List |  |  |
StartTaskExecution | Starts a specific invocation of a sync task. | Write | task* |  |
TagResource | Applies a key-value pair to an AWS resource. | Write | agent |  |
location |  |
task |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | This operation removes one or more tags from the specified resource. | Tagging | agent |  |
location |  |
task |  |
| aws:TagKeys |
UpdateAgent | Updates the name of an agent. | Write | agent* |  |
UpdateTask | Updates the metadata associated with a sync task. | Write | task* |  |

## Resources Defined by DataSync

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table.

Resource Types | ARN | Condition Keys
--- | --- | ---
agent | `arn:${Partition}:datasync:${Region}:${AccountId}:agent/${AgentId}` | aws:ResourceTag/${TagKey}
location | `arn:${Partition}:datasync:${Region}:${AccountId}:location/${LocationId}` | aws:ResourceTag/${TagKey}
task | `arn:${Partition}:datasync:${Region}:${AccountId}:task/${TaskId}` | aws:ResourceTag/${TagKey}
taskexecution | `arn:${Partition}:datasync:${Region}:${AccountId}:task/${TaskId}/execution/${ExecutionId}` |

## Condition Keys for DataSync

DataSync defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table.

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference.

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters create requests based on the allowed set of values for each of the tags. | String
aws:ResourceTag/${TagKey} | Filters actions based on tag-value associated with the resource. | String
aws:TagKeys | Filters create requests based on the presence of mandatory tags in the request. | String

On this page:

- Actions Defined by DataSync
- Resources Defined by DataSync
- Condition Keys for DataSync

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more